@@ -4,9 +4,9 @@
 File format for 96-well plate layouts.
 """
 
-__version__ = '0.6.0'
+__version__ = '0.7.0'
 
 from .util import *
-from .load import *
-from .verify import show
-from . import verify
+from .file import *
+from .plot import show
+from . import plot
